Structs
- Baseline
Section - The
[baseline]section. - Scoped
Preset - A
[[baseline.scoped]]entry that applies a preset to a specific directory. - Toml
Config - Top-level TOML config file structure.
- Toml
Rule - A single
[[rule]]entry.
[baseline] section.[[baseline.scoped]] entry that applies a preset to a specific directory.[[rule]] entry.