Module git_diff

Module git_diff 

Structs

DiffInfo
Changed files and line ranges from a git diff.

Enums

GitDiffError

Functions

detect_base_ref
Detect the base ref from CI environment variables, falling back to “main”.
diff_info
Parse a git diff to extract changed files and their changed line ranges.
repo_root
Get the repository root directory.