pub struct DiffInfo {
pub changed_lines: HashMap<PathBuf, Vec<RangeInclusive<usize>>>,
}Expand description
Changed files and line ranges from a git diff.
Fields
changed_lines: HashMap<PathBuf, Vec<RangeInclusive<usize>>>Map of relative file path to list of changed line ranges.
Implementations