pub fn detect_project(dir: &Path) -> ProjectTypeExpand description
Detect the project type by checking for config files in the given directory.
pub fn detect_project(dir: &Path) -> ProjectTypeDetect the project type by checking for config files in the given directory.