Modules
- banned_
dependency - banned_
import - banned_
pattern - factory
- file_
presence - ratchet
- required_
pattern - tailwind_
dark_ mode - tailwind_
theme_ tokens - window_
pattern
Structs
- Fix
- Machine-actionable fix data for a violation.
- Scan
Context - The file currently being scanned.
- Violation
- A single violation emitted by a rule.
Enums
- Rule
Build Error - Errors that can occur when constructing a rule from config.
Traits
- Rule
- A lint rule that checks source files for violations.