collect_class_attributes

Function collect_class_attributes 

pub fn collect_class_attributes(
    tree: &Tree,
    source: &[u8],
) -> Vec<Vec<ClassFragment>>
Walk the syntax tree and collect class strings from all className/class JSX attributes.

Returns Vec<Vec<ClassFragment>> — outer vec is per-attribute, inner vec is all class string fragments from that attribute.