pub struct NoNestedComponentsRule { /* private fields */ }Expand description
Flags React component definitions that appear inside another component.
Nested component definitions cause the inner component to be re-created on every render of the outer component, destroying and remounting its DOM and losing all state.
Implementations
Sourceimpl NoNestedComponentsRule
impl NoNestedComponentsRule
pub fn new(config: &RuleConfig) -> Result<Self, RuleBuildError>