pub struct NoObjectDepArrayRule { /* private fields */ }Expand description
Flags object or array literals inside useEffect/useMemo/useCallback
dependency arrays.
Object and array literals create new references on every render, defeating the purpose of the dependency array.
Implementations
Sourceimpl NoObjectDepArrayRule
impl NoObjectDepArrayRule
pub fn new(config: &RuleConfig) -> Result<Self, RuleBuildError>