Module window_pattern
code_
baseline
1.6.0
Module window_
pattern
Module Items
Structs
In code_
baseline::
rules
code_baseline
::
rules
Module
window_
pattern
Structs

Window
Pattern
Rule
Enforces that when a trigger pattern appears, a required pattern must also appear within a configurable window of lines.