apply_fixes

Function apply_fixes 

pub fn apply_fixes(result: &ScanResult, dry_run: bool) -> usize
Apply fixes from violations to source files. Returns the number of fixes applied. Fixes are targeted to the specific line where the violation occurred to avoid accidentally replacing a different occurrence of the same pattern.