Structs
- Diff
Info - Changed files and line ranges from a git diff.
Enums
Functions
- detect_
base_ ref - Detect the base ref from CI environment variables, falling back to “main”.
- diff_
info - Parse a git diff to extract changed files and their changed line ranges.
- repo_
root - Get the repository root directory.