Re-exports
pub use max_component_size::MaxComponentSizeRule;pub use no_cascading_set_state::NoCascadingSetStateRule;pub use no_click_handler::NoDivClickHandlerRule;pub use no_click_handler::NoSpanClickHandlerRule;pub use no_derived_state_effect::NoDerivedStateEffectRule;pub use no_nested_components::NoNestedComponentsRule;pub use no_object_dep_array::NoObjectDepArrayRule;pub use no_outline_none::NoOutlineNoneRule;pub use no_regexp_in_render::NoRegexpInRenderRule;pub use prefer_use_reducer::PreferUseReducerRule;pub use require_img_alt::RequireImgAltRule;
Modules
- max_
component_ size - no_
cascading_ set_ state - no_
click_ handler - no_
derived_ state_ effect - no_
nested_ components - no_
object_ dep_ array - no_
outline_ none - no_
regexp_ in_ render - prefer_
use_ reducer - require_
img_ alt
Structs
- Class
Fragment - A fragment of a class string extracted from a JSX className/class attribute.
Enums
- Lang
- Supported languages for AST parsing.
Functions
- collect_
class_ attributes - Walk the syntax tree and collect class strings from all className/class JSX attributes.
- count_
calls_ in_ scope - Count calls to a specific function within a node’s subtree, skipping nested component definitions.
- detect_
language - Detect language from file extension.
- extract_
classname_ strings - Extract string fragments from a className attribute value node.
- is_
component_ node - Check if a tree-sitter node represents a React component declaration.
- parse_
file - Parse a file into a tree-sitter syntax tree.